@@ -242,13 +242,17 @@ def push_csv2tog(job_id: int, file_path: str, access_token: str):
             "data_source": "fsm",
             "data_id": row["data_id"],
             "data": {
-                "call_uuid": row["call_id"],
+                "call_uuid": row["call_uuid"],
                 "conversation_uuid": row["conversation_uuid"],
                 "alternatives": data["alternatives"],
                 "audio_url": row["audio_url"],
                 "reftime": row["reftime"],
                 "prediction": row["prediction"],
-                "state": row["state"]
+                "state": row["state"],
+                "ack_slots": row["ack_slots"],
+                "end_state": row["end_state"],
+                "call_duration": row["call_duration"],
+                "state_transitions": row["state_transitions"]
             },
             "is_gold": False
         })
